==> pluginbase-1.5.88-sources.jar: org/bimserver/interfaces/objects/SObjectDefinition.java <==
package org.bimserver.interfaces.objects;

/******************************************************************************
 * Copyright (C) 2009-2017  BIMserver.org
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see {@literal<http://www.gnu.org/licenses/>}.
 *****************************************************************************/
import java.util.ArrayList;
import java.util.List;

import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlTransient;

import org.bimserver.shared.meta.SBase;
import org.bimserver.shared.meta.SClass;
import org.bimserver.shared.meta.SField;


@XmlRootElement
public class SObjectDefinition extends STypeDefinition implements SBase
{

	@XmlTransient
	private static SClass sClass;
	private List<SParameterDefinition> parameters = new ArrayList<SParameterDefinition>();
	
	@XmlTransient
	public SClass getSClass() {
		return sClass;
	}
	
	public static void setSClass(SClass sClass) {
		SObjectDefinition.sClass = sClass;
	}

	public Object sGet(SField sField) {
		if (sField.getName().equals("parameters")) {
			return getParameters();
		}
		throw new RuntimeException("Field " + sField.getName() + " not found");
	}
	@SuppressWarnings("unchecked")

	public void sSet(SField sField, Object val) {
		if (sField.getName().equals("parameters")) {
			setParameters((List<SParameterDefinition>)val);
			return;
		}
		throw new RuntimeException("Field " + sField.getName() + " not found");
	}
	
	public List<SParameterDefinition> getParameters() {
		return parameters;
	}

	public void setParameters(List<SParameterDefinition> parameters) {
		this.parameters = parameters;
	}
	
}

==> pluginbase-1.5.92-sources.jar: org/bimserver/interfaces/objects/SObjectDefinition.java <==
package org.bimserver.interfaces.objects;

/******************************************************************************
 * Copyright (C) 2009-2017  BIMserver.org
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see {@literal<http://www.gnu.org/licenses/>}.
 *****************************************************************************/
import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlTransient;
import org.bimserver.shared.meta.*;
import javax.xml.bind.annotation.XmlRootElement;


@XmlRootElement
public class SObjectDefinition extends STypeDefinition implements SBase
{

	@XmlTransient
	private static SClass sClass;
	private List<SParameterDefinition> parameters = new ArrayList<SParameterDefinition>();
	
	@XmlTransient
	public SClass getSClass() {
		return sClass;
	}
	
	public static void setSClass(SClass sClass) {
		SObjectDefinition.sClass = sClass;
	}

	public Object sGet(SField sField) {
		if (sField.getName().equals("parameters")) {
			return getParameters();
		}
		throw new RuntimeException("Field " + sField.getName() + " not found");
	}
	@SuppressWarnings("unchecked")

	public void sSet(SField sField, Object val) {
		if (sField.getName().equals("parameters")) {
			setParameters((List<SParameterDefinition>)val);
			return;
		}
		throw new RuntimeException("Field " + sField.getName() + " not found");
	}
	
	public List<SParameterDefinition> getParameters() {
		return parameters;
	}

	public void setParameters(List<SParameterDefinition> parameters) {
		this.parameters = parameters;
	}
	
}
